"""Numpy transforms"""
from .add_topographic_data import AddTopographicDataIterDataPipe as AddTopographicData
from .add_zeroed_future_pv import AddZeroedFutureDataIterDataPipe as AddZeroedFutureData
from .align_gsp_to_5_min import AlignGSPto5MinIterDataPipe as AlignGSPto5Min
from .encode_space_time import EncodeSpaceTimeIterDataPipe as EncodeSpaceTime
from .extend_timestamps_to_future import (
    ExtendTimestepsToFutureIterDataPipe as ExtendTimestepsToFuture,
)
from .save_t0_time import SaveT0TimeIterDataPipe as SaveT0Time
from .sun_position import AddSunPositionIterDataPipe as AddSunPosition



"""Xarray transforms"""
from .add_t0idx_and_sample_period_duration import (
    AddT0IdxAndSamplePeriodDurationIterDataPipe as AddT0IdxAndSamplePeriodDuration,
)
from .convert_satellite_to_int import ConvertSatelliteToInt8IterDataPipe as ConvertSatelliteToInt8
from .convert_to_nwp_target_times import (
    ConvertToNWPTargetTimeIterDataPipe as ConvertToNWPTargetTime,
)
from .downsample import DownsampleIterDataPipe as Downsample
from .ensure_n_pv_systems_per_example import (
    EnsureNPVSystemsPerExampleIterDataPipe as EnsureNPVSystemsPerExample,
)
from .get_contiguous_time_periods import (
    GetContiguousT0TimePeriodsIterDataPipe as GetContiguousT0TimePeriods,
)
from .normalize import NormalizeIterDataPipe as Normalize
from .pv_power_rolling_window import PVPowerRollingWindowIterDataPipe as PVPowerRollingWindow
from .reproject_topographic_data import ReprojectTopographyIterDataPipe as ReprojectTopography
